clear all;

%%%
% File for fitting ODE to SIMA decay response 
% This is tailored to the experiment in surge, can be adapted to sway and
% yaw
%%%

%%% Style %%%
% general graphics, this will apply to any figure you open
% (groot is the default figure object).
set(groot, ...
'DefaultFigureColor', 'w', ...
'DefaultAxesLineWidth', 0.5, ...
'DefaultAxesXColor', 'k', ...
'DefaultAxesYColor', 'k', ...
'DefaultAxesFontUnits', 'points', ...
'DefaultAxesFontSize', 10, ...
'DefaultAxesFontName', 'Helvetica', ...
'DefaultLineLineWidth', 1, ...
'DefaultTextFontUnits', 'Points', ...
'DefaultTextFontSize', 10, ...
'DefaultTextFontName', 'Helvetica', ...
'DefaultAxesBox', 'off', ...
'DefaultAxesTickLength', [0.02 0.025]);
 
% set the tickdirs to go out - need this specific order
set(groot, 'DefaultAxesTickDir', 'out');
set(groot, 'DefaultAxesTickDirMode', 'manual');
%%%%%%%%%%%%%

% Specify the file path
file_path = 'C:\decay_file_path';

%%% - IMPORT DATA - %%%
data = tdmsread(file_path);

%Assign data to variable
output = data{1, 2};

my_time = output.("TIME [s]")(:);
time = my_time - my_time(1); 
surge = output.("N_m_ []")(:);

%define the ODE parameters based on values from SIMA
mSIMA = 13.99e+06;
a_0SIMA = 8.2e6;%5.4144e+06; %From Figure A.7 in Windmoor report.
scale = 40;
rho = 1.025;
M = (mSIMA+a_0SIMA)/scale^3/rho; %structrual and added mass from SIMA
D1 = 0.139;
D2 = 389; %quadratic damping%
K = 62.2; %stiffness from mooring in HLCC

t_ref = 0;
x_ref = @(t) 0 + (0.25-0)*(t>=t_ref); %reference for position in decay
f = @(t, x) [x(2); 1/M * (-K*(x(1)-x_ref(t)) - D1*x(2) -D2*x(2)*abs(x(2)))]; %mass-spring-damper
x0 = [0 0]; %initial values

[t,x] = ode45(@(t,x) f(t,x), time, x0);

[maxOde,indMaxOde] = max(x(:,1));
[maxSIMA,indMaxSIMA] = max(surge);

ref = 0.25* ones(length(t),1);

%plot
figure
hold on
plot(time-time(indMaxSIMA), surge)
plot(time-time(indMaxOde), x(:,1))
plot(time-time(indMaxOde), ref, LineStyle="--", Color=[0 0 0])
hold off
xlim([-10 100])
legend( 'SIMA','ode45 solution' , 'reference value')
xlim([-30 150])
xlabel('Time [s]')
ylabel('Position, \eta_1 [m]')
title('ODE45 position solved for surge')
