clear all

%%% Style %%%
% general graphics, this will apply to any figure you open
% (groot is the default figure object).
set(groot, ...
'DefaultFigureColor', 'w', ...
'DefaultAxesLineWidth', 0.5, ...
'DefaultAxesXColor', 'k', ...
'DefaultAxesYColor', 'k', ...
'DefaultAxesFontUnits', 'points', ...
'DefaultAxesFontSize', 10, ...
'DefaultAxesFontName', 'Helvetica', ...
'DefaultLineLineWidth', 1, ...
'DefaultTextFontUnits', 'Points', ...
'DefaultTextFontSize', 10, ...
'DefaultTextFontName', 'Helvetica', ...
'DefaultAxesBox', 'off', ...
'DefaultAxesTickLength', [0.02 0.025]);
 
% set the tickdirs to go out - need this specific order
set(groot, 'DefaultAxesTickDir', 'out');
set(groot, 'DefaultAxesTickDirMode', 'manual');
%%%%%%%%%%%%%

run processing.m

fold = 'C:\location_for_storing_plot';

%% Make figure
nLines = 4; 
nCols = 3; 
handles = zeros(4,3);

window = [time((1)) time((end))];
figure('Position',[1970 1 0.5*2511 0.5*1361],'Visible','On'); 

maxb12 = max([bias_surge;bias_sway]) + std([bias_surge;bias_sway]); 
minb12 = min([bias_surge;bias_sway]) - std([bias_surge;bias_sway]);
maxUV = max([velLocFilt(:,1) ; velLocFilt(:,2)])+std([velLocFilt(:,1);velLocFilt(:,2)]);
minUV = min([velLocFilt(:,1) ; velLocFilt(:,2)])-std([velLocFilt(:,1);velLocFilt(:,2)]);
maxNE = max([Nfilt ; Efilt])+std([Nfilt ; Efilt]);
minNE = min([Nfilt ; Efilt])-std([Nfilt ; Efilt]);

handles(1,1) = subplot(nLines,nCols,1);
plot(time,tau_ref_surge,[time(1) time(end)],mean(tau_ref_surge)*[1 1],'k--');
ylabel('\tau_1 [N]');

handles(1,2) = subplot(nLines,nCols,2);
plot(time,tau_ref_sway,[time(1) time(end)],mean(tau_ref_sway)*[1 1],'k--')
ylabel('\tau_2 [N]');

handles(1,3) = subplot(nLines,nCols,3);
plot(time,tau_ref_yaw,[time(1) time(end)],mean(tau_ref_yaw)*[1 1],'k--')
ylabel('\tau_3 [Nm]');
legend('Input load');

handles(2,1) = subplot(nLines,nCols,4);
plot(time,bias_surge,[time(1) time(end)],-mean(tau_ref_surge)*[1 1],'k--')
if ~isnan(minb12) && ~isnan(maxb12); ylim([minb12 maxb12]); end
ylabel('b_1 [N]');

handles(2,2) = subplot(nLines,nCols,5);
plot(time,bias_sway,[time(1) time(end)],-mean(tau_ref_sway)*[1 1],'k--')
if ~isnan(minb12) && ~isnan(maxb12); ylim([minb12 maxb12]); end
ylabel('b_2 [N]');


handles(2,3) = subplot(nLines,nCols,6);
plot(time,bias_yaw,[time(1) time(end)],-mean(tau_ref_yaw)*[1 1],'k--')
ylabel('b_3 [Nm]');
legend('Estimated bias');
 
handles(3,1) = subplot(nLines,nCols,7);
plot(time,nu_LF_surge,time,velLocFilt(:,1))
xlim(window);
ylabel('u [m/s]');
ylim([minUV maxUV]);

handles(3,2) = subplot(nLines,nCols,8);
plot(time,nu_LF_sway,time,velLocFilt(:,2))
xlim(window);
ylabel('v [m/s]');
ylim([minUV maxUV]);

handles(3,3) = subplot(nLines,nCols,9);
plot(time,nu_LF_yaw,time,velLocFilt(:,3))
xlim(window);
ylabel('r [deg/s]');
legend('NPO','Measured+filtered');

handles(4,1) = subplot(nLines,nCols,10);
hold on
plot(time,eta_MoCap_surge,'Color', [0.9290 0.6940 0.1250])
plot(time,Nfilt, 'Color', [0.8500 0.3250 0.0980])
plot(time, eta_LF_surge, 'Color', [0 0.4470 0.7410])
hold off
xlim(window);
ylabel('N [m]');
ylim([minNE maxNE]);
xlabel('Time [s]');

handles(4,2) = subplot(nLines,nCols,11);
hold on
plot(time,eta_MoCap_sway,'Color', [0.9290 0.6940 0.1250])
plot(time,Efilt, 'Color', [0.8500 0.3250 0.0980])
plot(time, eta_LF_sway, 'Color', [0 0.4470 0.7410])
hold off
xlim(window);
ylabel('E [m]');
ylim([minNE maxNE]);
xlabel('Time [s]');

handles(4,3) = subplot(nLines,nCols,12);
hold on
plot(time,eta_MoCap_yaw,'Color', [0.9290 0.6940 0.1250])
plot(time,psiFilt, 'Color', [0.8500 0.3250 0.0980])
plot(time, eta_LF_yaw, 'Color', [0 0.4470 0.7410])
hold off
xlim(window);
ylabel('\psi [deg]');
legend('Raw eta','Measured+Filtered','NPO');
xlabel('Time [s]');

squeeze_axes(handles)

saveas(gcf,['observer' num2str(file)],'png');
