clear all

%%% -   Explaination    -   %%%
% Generate plots based on simulation loaded in processing.m
%%%     %%%     %%%     %%%

%%% Define plot style %%%
% (groot is the default figure object).
set(groot, ...
'DefaultFigureColor', 'w', ...
'DefaultAxesLineWidth', 0.5, ...
'DefaultAxesXColor', 'k', ...
'DefaultAxesYColor', 'k', ...
'DefaultAxesFontUnits', 'points', ...
'DefaultAxesFontSize', 10, ...
'DefaultAxesFontName', 'Helvetica', ...
'DefaultLineLineWidth', 1.5, ...
'DefaultTextFontUnits', 'Points', ...
'DefaultTextFontSize', 10, ...
'DefaultTextFontName', 'Helvetica', ...
'DefaultAxesBox', 'off', ...
'DefaultAxesTickLength', [0.02 0.025]);
 
% set the tickdirs to go out - need this specific order
set(groot, 'DefaultAxesTickDir', 'out');
set(groot, 'DefaultAxesTickDirMode', 'manual');
%%%%%%%%%%%%%

run processing.m    %Get data from running processing

%Define folder for storage of figures
fold = 'C:\Figures';

%Plot measured position, wf motion, lf motion and offline filtered position
%in surge for simulation
figure('Renderer', 'painters', 'Position', [50 50 900 600])
hold on
plot(time,eta_MoCap_surge)
plot(time,eta_WF_surge)
plot(time, eta_LF_surge)
plot(time, Nfilt(:))
hold off
xlabel('Time [s]')
ylabel('Motions [m]')
title('\eta [surge]')
legend('\eta_{MoCap}','\eta_{WF}','\eta_{LF}', 'Nfilt')
ax = gcf;
file = fullfile(fold, 'surge.jpg');
exportgraphics(ax,file)


%Make a sliced plot for signals in surge 
figure('Renderer', 'painters', 'Position', [50 50 900 600])
hold on
plot(time,eta_MoCap_surge)
plot(time,eta_WF_surge)
plot(time, eta_LF_surge)
plot(time, Nfilt(:))
hold off
xlim([100 150])
xlabel('Time [s]')
ylabel('Motions [m]')
title('Sliced \eta [surge]')
legend('\eta_{MoCap}','\eta_{WF}','\eta_{LF}', 'Nfilt')
ax = gcf;
file = fullfile(fold, 'surge_sliced.jpg');
exportgraphics(ax,file)


%Comparision between position, estimates and filtered position in sway
figure('Renderer', 'painters', 'Position', [50 50 900 600])
hold on
plot(time,eta_MoCap_sway)
plot(time,eta_WF_sway)
plot(time, eta_LF_sway)
plot(time, Efilt(:))
hold off
xlabel('Time [s]')
ylabel('Motions [m]')
title('\eta [sway]')
legend('\eta_{MoCap}', '\eta_{WF}','\eta_{LF}', 'Efilt')
ax = gcf;
file = fullfile(fold, 'sway.jpg');
exportgraphics(ax,file)

%Comparision between position, estimates and filtered position in yaw
figure('Renderer', 'painters', 'Position', [50 50 900 600])
hold on
plot(time,eta_MoCap_yaw)
plot(time,eta_WF_yaw)
plot(time, eta_LF_yaw)
plot(time, psiFilt(:))
hold off
xlabel('Time [s]')
ylabel('Motions [deg]')
title('\eta [yaw]')
legend('\eta_{MoCap}', '\eta_{WF}','\eta_{LF}', '\psi-filt')
ax = gcf;
file = fullfile(fold, 'yaw.jpg');
exportgraphics(ax,file)

%Plot velocities and derived filtered velocities for all three DOF
figure('Renderer', 'painters', 'Position', [50 50 900 600])
hold on
plot(time,nu_LF_surge)
plot(time, velLocFilt(:,1))
plot(time,nu_LF_sway)
plot(time, velLocFilt(:,2))
plot(time, nu_LF_yaw)
plot(time, velLocFilt(:,3))
hold off
xlabel('Time [s]')
ylabel('Velocity [m/s]')
title('\nu (velocity)')
legend('\nu_{surge}', 'u','\nu_{sway}', 'v','\nu_{yaw}', 'r')
ax = gcf;
file = fullfile(fold, 'nu.jpg');
exportgraphics(ax,file)

%Define references for bias force in surge
mean_val = mean(tau_ref_surge(:));
mean_series = mean_val * ones(1, length(time));
%Define references for bias force in yaw
mean_ref_yaw = mean(tau_ref_yaw(:));
mean_series_yaw = mean_ref_yaw * ones(1,length(time));

%Compare bias force and reference mooring force in surge
figure('Renderer', 'painters', 'Position', [50 50 900 600])
hold on
plot(time,tau_ref_surge)
plot(time,bias_surge)
plot(time, -mean_series, 'color', 'k', LineStyle='--')
hold off
xlabel('Time [s]')
ylabel('Force [N]')
title('\tau vs bias in surge')
legend('\tau_{surge}', 'bias_{surge}', '-\tau mean')
ax = gcf;
file = fullfile(fold, 'tau_bias_surge.jpg');
exportgraphics(ax,file)

%Compare bias force and reference mooring force in yaw
figure('Renderer', 'painters', 'Position', [50 50 900 600])
hold on
plot(time,tau_ref_yaw)
plot(time,bias_yaw)
plot(time, -mean_series_yaw, 'color', 'k', LineStyle='--')
hold off
xlabel('Time [s]')
ylabel('Force [Nm/deg]')
title('\tau vs bias in yaw')
legend('\tau_{yaw}', 'bias_{yaw}', '-\tau mean')
ax = gcf;
file = fullfile(fold, 'tau_bias_yaw.jpg');
exportgraphics(ax,file)