package no.marintek.generic.control;

import java.util.Set;

/**
 * A reference to a named part of the numerical model. Contains one or more component which is referred to by its name. For example, a
 * {@link SignalEntity} referring to a SIMO body contains a component named "position" which contains an array of the current position of the body.
 * 
 */
public interface SignalEntity {

	/**
	 * 
	 * @return {@link Set} of available components
	 */
	public Set<String> getAvailableComponents();

	/**
	 * Get the values for the signal component with a given name. Throws an {@link IllegalArgumentException} if no component has the given name.
	 * 
	 * @param name
	 *            Name of component
	 * @return Array of values for component with given name
	 */
	double[] get(String name);

	/**
	 * Sets the values of a signal component. Throws an {@link IllegalArgumentException} if no component has the given name.
	 * 
	 * @param name
	 *            Type name
	 * @param values
	 *            Array with values to be set
	 */
	public void set(String name, double[] values);


}